from distutils.core import setup

setup(
        name         = 'tsc_nester',
        version      = '1.0.0',
        py_modules   = ['tst_nester'],
        author       = 'hfpython by tiscal404',
        author_email = 'hfpython@headfirstlabs.com',
        url          = 'http://www.headfirstlabs.com',
        description  = 'A simple printer of nested lists',
    )
